/*
    Servo mount for raspberry pi camera.
    Eirik Taylor, 04.07.2016
*/

module raspiCameraServo()
difference()
{
    $fn = 30;
    
    baseWidth = 32;
    baseLength = 24;
    baseThickness = 3;
    
    cameraSupportBufferWidth = 10;
    cameraSupportBufferLength = 5;
    cameraSupportBufferHeight = 1.5;
    
    cameraHoleSize = 8.6;
    cameraHoleLengthWiseOffset = 9.2;
    
    mountingHoleSpacing = 20.6;
    mountingSpacerDiameter = 5;
    mountingSpacerHeight = 2.3;
    mountingHoleDiameter = 2.4;
    
    servoHoleSinkageDegree = 0.3;
    servoScrewHoleDiamter = 2.7;
    servoScrewHoleLargeDiamter = 5.8;
    servoScrewHoleZoffset = baseThickness + servoScrewHoleLargeDiamter/2 + 0.5;
    servoScrewHoleXoffset = 1;
    
    servoHornBracketThickness = 2 * baseThickness;
    servoHornHoleDiameter = 5.0;
    servoHornHoleDepth = 3;
    
    union()
    {
        // Main baseplate
        translate([-baseWidth/2, -cameraHoleLengthWiseOffset, 0])
        cube([baseWidth, baseLength, baseThickness]);
        
        // Small camera support deal
        /*translate([-cameraSupportBufferWidth/2, -cameraHoleLengthWiseOffset, -cameraSupportBufferHeight])
        cube([cameraSupportBufferWidth, cameraSupportBufferLength, cameraSupportBufferHeight]);*/
        
        // Support pillars
        translate([-mountingHoleSpacing/2, 0, baseThickness])
    cylinder(h=mountingSpacerHeight, d=mountingSpacerDiameter, center=false);
        
        translate([mountingHoleSpacing/2, 0, baseThickness])
    cylinder(h=mountingSpacerHeight, d=mountingSpacerDiameter, center=false);
        
        // Servo mounting support
        difference()
        {
            translate([-baseWidth/2-servoHornBracketThickness, -cameraHoleLengthWiseOffset+baseLength/2, baseThickness/2])
            rotate([0, 90, 0])
            cylinder(h=servoHornBracketThickness, d=baseLength, center=false);
            
            translate([-300, -300, -600])
            cube([600, 600, 600]);
        }
    }
    
    // Hole for the camera
    translate([-cameraHoleSize/2, -cameraHoleSize/2, -1-cameraSupportBufferHeight])
    cube([cameraHoleSize, cameraHoleSize, baseThickness+cameraSupportBufferHeight+2]);
    
    // Mounting holes
    translate([-mountingHoleSpacing/2, 0, -1-cameraSupportBufferHeight])
    cylinder(h=cameraSupportBufferHeight+baseThickness+2+mountingSpacerHeight, d=mountingHoleDiameter, center=false);
    
    translate([mountingHoleSpacing/2, 0, -1-cameraSupportBufferHeight])
    cylinder(h=cameraSupportBufferHeight+baseThickness+2+mountingSpacerHeight, d=mountingHoleDiameter, center=false);
    
    // Holes for the servo screw
    translate([-baseWidth/2-servoHornBracketThickness/2, -cameraHoleLengthWiseOffset+baseLength/2+servoScrewHoleXoffset, baseThickness/2-1+servoScrewHoleZoffset])
    rotate([0, 90, 0])
    cylinder(h=servoHornBracketThickness+2, d=servoScrewHoleDiamter, center=true);
    
    sinkageAmount = servoHoleSinkageDegree*baseThickness;
    
    translate([-baseWidth/2-sinkageAmount+0.01, -cameraHoleLengthWiseOffset+baseLength/2+servoScrewHoleXoffset, baseThickness/2-1+servoScrewHoleZoffset])
    rotate([0, 90, 0])
    cylinder(h=sinkageAmount, d=servoScrewHoleLargeDiamter, center=false);
    
    // Hole for the servo horn
    translate([-baseWidth/2-servoHornBracketThickness-0.01, -cameraHoleLengthWiseOffset+baseLength/2+servoScrewHoleXoffset, baseThickness/2-1+servoScrewHoleZoffset])
    rotate([0, 90, 0])
    cylinder(h=servoHornHoleDepth, d=servoHornHoleDiameter, center=false);
}

raspiCameraServo();