/*

    Complete OpenROV electronics housing 3D Model
    Eirik Taylor, 11.06.2016

*/

use <subModules/openROVmainTube.scad>
use <subModules/cameraModule.scad>
use <subModules/homePlugBoard.scad>
use <subModules/hs422servo.scad>
use <subModules/openRovInterfaceBoard_all_top_mount.scad>
use <subModules/raspberryPiBoard_top_mount.scad>
use <subModules/rpiMountingHoles.scad>
use <subModules/homePlugMountingStruct.scad>
use <subModules/servoMountingBracket.scad>

module openROVelectronicsHousingRevisionOne(renderEndCaps, renderBasePlate, subtractServoMount)
// Use union for mock-up mode, in the end subtraction of the various modules is the goal
//union()
difference()
{
    //$fn=40;
    
    EndCapWidth = 6;
    MainPlateThickness = 6;
    
    MainLength = 156;
    MainPlateWidth = 88;
    
    GlueSectionWidth = 15;
    GlueSectionCenterSpacing = 30;
    
    /**** All support material ****/
    union()
    {
        rotate([0, 180, 0])
        {
            if (renderBasePlate != 0) BasePlate(EndCapWidth, MainPlateThickness, MainLength, MainPlateWidth, GlueSectionWidth, GlueSectionCenterSpacing);
            if (renderEndCaps != 0) EndCaps(EndCapWidth, MainPlateThickness, MainLength, MainPlateWidth, GlueSectionWidth, GlueSectionCenterSpacing);
        }
        
        if (renderBasePlate != 0)
        {
            // Interface board support structure
            interfaceBoardSupportLength = 64.8;
            interfaceBoardSupportWidth = 80;
            interfaceBoardSupportHeight = 6;
            endCapOffsetFOrinterfaceBoard = 8;
            interfaceBoardSupportOffset = 2;
            
            translate([-interfaceBoardSupportWidth/2+interfaceBoardSupportOffset, endCapOffsetFOrinterfaceBoard, -MainPlateThickness/2])
            cube([interfaceBoardSupportWidth, interfaceBoardSupportLength, MainPlateThickness/2+interfaceBoardSupportHeight]);
            
            // Raspberry pi
            Rpi_Mounting_pillars_diamter = 8;
            Rpi_Mounting_pillars_height = 20;
            
            translate([0, 115, 0])
            rotate([0, 0, 90])
            rpiMountingHoles(Rpi_Mounting_pillars_diamter, Rpi_Mounting_pillars_height);
           
            // tether connector need to be fastened
            TetherConnectionHeight = 20;
            TetherConnectionLength = 37;
            TetherConnectionWidth = 12;
            
            TetherConnectionLength_Offset = -9.5;
            TetherConnectionWidth_Offset = 32;
            
            translate([-TetherConnectionLength/2 + TetherConnectionLength_Offset, -TetherConnectionWidth/2 + TetherConnectionWidth_Offset, -MainPlateThickness/2 - TetherConnectionHeight])
            cube([TetherConnectionLength, TetherConnectionWidth, TetherConnectionHeight]);
            
            // Mounting jig for the camera servo
            if (subtractServoMount == 0)
            {
                translate([0, 116, -MainPlateThickness/2])
                ServoMountingBracket(MainPlateThickness, 0);
            }
        }
    }
    
    /**** Actual objects are subtracted ****/
    
    // Interface board to the OpenROV connector
    translate([2.8, 40, 3.0])
    rotate([0, 0, 90])
    openRovInterfaceBoard();
    
    // Raspberry Pi 2 board
    translate([0, 105, 34])
    rotate([0, 180, 90])
    raspberryPiBoard();
    
    // Tether interface board
    translate([-6, 32, -3.0])
    rotate([0, 180, 180])
    homePlugBoard();
    
    // Sunken bolt holes for the homeplug board
    BoltSinkage = 4.5;
    translate([-9.5, 32.5, MainPlateThickness/2 - BoltSinkage])
    homePlugMountingStruct(8, BoltSinkage, 0, 0, 0, 0);
    
    // The servo mount
    translate([-10, 143, -24])
    rotate([90, 0, 0])
    hs422servo(30);
    
    if (subtractServoMount == 1)
    {
        translate([0, 116, -MainPlateThickness/2])
        ServoMountingBracket(MainPlateThickness+1, 0.4);
    }
    
    // Camera module, just to see if there is room for it
    // Need to make a bit to mount the camera
    /*translate([-6, 98, -25])
    rotate([90, 0, 0])
    cameraModule();*/
}

module openROVelectronicsHousingRevisionOneEndCap()
difference()
{
    rotate([90, 0, 0])
    openROVelectronicsHousingRevisionOne(1, 0, 0);
    
    translate([-150, -150, 80])
    cube([300, 300, 300]);
}

module openROVelectronicsHousingRevisionOneBasePlateMain()
difference()
{
    MainPlateThickness = 6;
    
    translate([0, 0, MainPlateThickness/2])
    openROVelectronicsHousingRevisionOne(0, 1, 1);
    
    translate([-500, -500, -60])
    cube([1000, 1000, 60]);
}

module openROVelectronicsHousingRevisionOneBasePlateBottom()
difference()
{
    MainPlateThickness = 6;
    
    translate([0, 0, -MainPlateThickness/2])
    rotate([0, 180, 0])
    openROVelectronicsHousingRevisionOne(0, 1, 0);
    
    difference()
    {
        translate([-500, -500, -60 + 0.01])
        cube([1000, 1000, 60]);
        
        translate([0, 116, 0])
        rotate([0, 180, 0])
        ServoMountingBracket(MainPlateThickness, 0);
    }
}

module printableBaseplateBottom()
union()
{
    // Get the stand-offs
    difference()
    {
        openROVelectronicsHousingRevisionOneBasePlateBottom();
        
        translate([-250, 100, -250])
        cube(500);  
    }
    
    // Get the servo mounting stuff
    translate([0, -10, 126])
    rotate([270, 0, 0])
    difference()
    {
        openROVelectronicsHousingRevisionOneBasePlateBottom();
        
        translate([-250, -400, -250])
        cube(500);  
    }
}

openROVelectronicsHousingRevisionOne(1, 1, 0);

//openROVelectronicsHousingRevisionOneEndCap();

//openROVelectronicsHousingRevisionOneBasePlateMain();

//openROVelectronicsHousingRevisionOneBasePlateBottom();

//printableBaseplateBottom();