/*

    HomePlug PCB 3D Model
    Eirik Taylor, 01.06.2016

*/

module homePlugBoard() 
//Pillars where the mounting holes for the PCB need to go. Also an exclusion box for the area needed for the PCB
union()
{
    // Size definitions
    PCB_width = 63.5;
    PCB_length = 44.4;
    PCB_height_topside = 16;
    PCB_board_thickness = 0.9;
    PCB_height_bottomside = 5.0;
    
    // Tolerances in printing
    PCB_perimeter_tolerance = 1; // Placed all around the PCB
    Printing_shrinkage = 0.3;
    
    // Stand-offs for mounting holes
    PCB_stand_off_size = 10;
    PCB_screw_hole_dia = 4.7;
    
    // Mounting holes
    Mounting_hole1_X = 14.3;
    Mounting_hole1_Y = 21.7;
    
    Mounting_hole2_X = 42.0;
    Mounting_hole2_Y = 21.7;
    
    // Special stuff for some PCB items
    NotchDepth = 2;
    ForwardNotchOffset = 2;
    SideNotchesOffset =  1.5;
    
    // Center everything
    translate([-PCB_width/2, -PCB_length/2, 0])
    
    // Mounting holes and PCB box
    union() 
    {
        difference() 
        {
            // PCB box
            totalWidth = PCB_width + 2*PCB_perimeter_tolerance;
            totalLength = PCB_length + 2*PCB_perimeter_tolerance;
            totalHeightOccupied = PCB_height_topside + PCB_height_bottomside + PCB_board_thickness;
            
            translate([-PCB_perimeter_tolerance, -PCB_perimeter_tolerance, 0])
            cube([totalWidth, totalLength, totalHeightOccupied]);
            
            // Create little stand-offs for the board to sit on
            startingHeightForMountingStandOffs = -0.01;
            
            // Pillar near the mains connector
            translate([Mounting_hole1_X, Mounting_hole1_Y, startingHeightForMountingStandOffs])
            difference()
            {
                cylinder(PCB_height_bottomside+0.01,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
                
                translate([-PCB_stand_off_size/2 - (PCB_stand_off_size - ForwardNotchOffset), -PCB_stand_off_size/2, PCB_height_bottomside-NotchDepth])
                cube([PCB_stand_off_size, PCB_stand_off_size, PCB_height_bottomside]);
                
                translate([-PCB_stand_off_size/2, -PCB_stand_off_size/2 - (SideNotchesOffset - PCB_stand_off_size), PCB_height_bottomside-NotchDepth])
                cube([PCB_stand_off_size, PCB_stand_off_size, PCB_height_bottomside]);
                
                translate([-PCB_stand_off_size/2, -1.5*PCB_stand_off_size+SideNotchesOffset, PCB_height_bottomside-NotchDepth])
                cube([PCB_stand_off_size, PCB_stand_off_size, PCB_height_bottomside]);
            }
            
            // Pillar near the ethernet plug
            translate([Mounting_hole2_X, Mounting_hole2_Y, startingHeightForMountingStandOffs])
            cylinder(PCB_height_bottomside+0.01,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
        }
        
        // Bolt holes
        translate([Mounting_hole1_X, Mounting_hole1_Y, -600])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        translate([Mounting_hole2_X, Mounting_hole2_Y, -600])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        
        // Hole for the ethernet connector
        StartingX_connector_outer = 14.3;
        Connector_padding_tolerance = 1;
        
        Connector_outer_width = 13.5;
        Connector_outer_length = 11.8;
        Connector_outer_height = PCB_height_topside;
        
        translate([PCB_width, StartingX_connector_outer-Connector_padding_tolerance, PCB_height_bottomside+PCB_board_thickness])
        cube([Connector_outer_width, Connector_outer_length+2*Connector_padding_tolerance, Connector_outer_height]);
        
        // Hole for the reset switch
        switch_length = 5;
        switch_width = 8;
        switch_height = 5;
        switch_starting_y = 3;
        
        translate([PCB_width-switch_length-switch_starting_y, -switch_width, PCB_height_bottomside+PCB_board_thickness])
        cube([switch_length+0.01, switch_width, switch_height]);
    }
}

homePlugBoard();
