/*

    HS-422 Hobby Servo 3D Model
    Eirik Taylor, 01.06.2016

*/

module hs422servo(mountingBoltLength) 
// Mounting holes and servo outline
union()
{
    // Size definitions
    motorBox_length = 39.88;
    motorBox_width = 19.82;
    motorBox_height = 26.67 + 11.68;
    
    mounting_wings_length = 52.84;
    mounting_wings_thickness = 9.35;
    mounting_wings_start_height = 26.67;
    
    tolerance = 0.4;  // Placed all around the motor box and mounting wings
    
    // Servo wheel sizes
    servo_wheel_diameter = 23.8;
    servo_wheel_thickness = 2.00;
    servo_wheel_starting_length = 9.66;
    servo_wheel_starting_height = 3.05;
    
    servo_axel_diameter = 8.8;
    
    // Mounting hole sizes/positions
    interhole_distance = 10.17;
    positions_one = 13.47;
    positions_two = 33.79;
    hole_diameter = 4.38 + 0.6;
    
    mounting_pillar_length = mountingBoltLength;
    
    /*******************************************************/
    
    // Center the design on the servo wheel
    translate([-servo_wheel_starting_length, -motorBox_width/2, 0])
    
    // Mounting holes and PCB box
    union() 
    {
        // Main box
        translate([-tolerance, -tolerance, 0])
        cube([motorBox_length+2*tolerance, motorBox_width+2*tolerance, motorBox_height]);
        
        // Wings for mounting bolts
        translate([-((mounting_wings_length - motorBox_length) / 2) - tolerance, -tolerance, mounting_wings_start_height])
        cube([mounting_wings_length+2*tolerance, motorBox_width+2*tolerance, mounting_wings_thickness]);
        
        // Servo wheel/actuator area
        translate([servo_wheel_starting_length, motorBox_width/2, motorBox_height+servo_wheel_starting_height])
        cylinder(servo_wheel_thickness, servo_wheel_diameter/2, servo_wheel_diameter/2);
        
        // Servo axel
        translate([servo_wheel_starting_length, motorBox_width/2, motorBox_height-0.01])
        cylinder(servo_wheel_starting_height+0.02, servo_axel_diameter/2, servo_axel_diameter/2);
        
        // Holes in wings
        translate([servo_wheel_starting_length-positions_one, motorBox_width/2-interhole_distance/2, -mounting_pillar_length + mounting_wings_start_height+0.01])
        cylinder(mounting_pillar_length, hole_diameter/2, hole_diameter/2);
        translate([servo_wheel_starting_length-positions_one, motorBox_width/2+interhole_distance/2, -mounting_pillar_length + mounting_wings_start_height+0.01])
        cylinder(mounting_pillar_length, hole_diameter/2, hole_diameter/2);
        
        translate([servo_wheel_starting_length+positions_two, motorBox_width/2-interhole_distance/2, -mounting_pillar_length + mounting_wings_start_height+0.01])
        cylinder(mounting_pillar_length, hole_diameter/2, hole_diameter/2);
        translate([servo_wheel_starting_length+positions_two, motorBox_width/2+interhole_distance/2, -mounting_pillar_length + mounting_wings_start_height+0.01])
        cylinder(mounting_pillar_length, hole_diameter/2, hole_diameter/2);
    }
}

hs422servo(60);
