/*

    Simple OpenROV main housing tube 3D Model
    Eirik Taylor, 11.06.2016

*/

module endCap(EndCapWidth, glueSectionWidth, GlueSectionCenterSpacing, MainPlateThickness)
difference()
{
    MainRadius = 46.5;
    CenterHoleRadius = 2;
    GlueInterfaceTolerance = 0.5;       // Extra padding placed around the glue interface slots
    
    DB25_connector_width = 42.00;
    DB25_connector_height = 10.905;
    DB25_connector_offset_height = 8.50 + 2.0;
    DB25_connector_offset_width = 12.00;
    
    // Main cylinder
    cylinder(EndCapWidth, MainRadius, MainRadius);
    
    // Center hole
    translate([0, 0, -1])
    cylinder(EndCapWidth+2, CenterHoleRadius, CenterHoleRadius);
    
    // Glue sections
    union()
    {
        translate([-GlueSectionCenterSpacing/2-glueSectionWidth-GlueInterfaceTolerance, -MainPlateThickness/2-GlueInterfaceTolerance, 0])
        cube([glueSectionWidth+2*GlueInterfaceTolerance, MainPlateThickness+2*GlueInterfaceTolerance, EndCapWidth]);
        
        translate([GlueSectionCenterSpacing/2-GlueInterfaceTolerance, -MainPlateThickness/2-GlueInterfaceTolerance, 0])
        cube([glueSectionWidth+2*GlueInterfaceTolerance, MainPlateThickness+2*GlueInterfaceTolerance, EndCapWidth]);
    }
    
    // Hole for the DB25 connector
    translate([-DB25_connector_offset_width, DB25_connector_offset_height, 0])
    cube([DB25_connector_width, DB25_connector_height, EndCapWidth]);
}

module mainPlate(MainLength, MainPlateWidth, MainPlateThickness, EndCapWidth, glueSectionWidth, GlueSectionCenterSpacing)
translate([0, 0 , -MainPlateThickness/2])
union()
{
    // Make the main plate
    translate([-MainPlateWidth/2, EndCapWidth, 0])
    cube([MainPlateWidth, MainLength-2*EndCapWidth, MainPlateThickness]);
    
    // Add stops for the glue sections
    translate([-GlueSectionCenterSpacing/2-glueSectionWidth, 0, 0])
    cube([glueSectionWidth, EndCapWidth, MainPlateThickness]);
    
    translate([GlueSectionCenterSpacing/2, 0, 0])
    cube([glueSectionWidth, EndCapWidth, MainPlateThickness]);
    
    translate([-GlueSectionCenterSpacing/2-glueSectionWidth, MainLength-EndCapWidth, 0])
    cube([glueSectionWidth, EndCapWidth, MainPlateThickness]);
    
    translate([GlueSectionCenterSpacing/2, MainLength-EndCapWidth, 0])
    cube([glueSectionWidth, EndCapWidth, MainPlateThickness]);
}

module EndCaps(EndCapWidth, MainPlateThickness, MainLength, MainPlateWidth, GlueSectionWidth, GlueSectionCenterSpacing)
union()
{
    rotate([270, 0, 0])
    union()
    {
        // End caps
        endCap(EndCapWidth, GlueSectionWidth, GlueSectionCenterSpacing, MainPlateThickness);
        translate([0, 0, MainLength-EndCapWidth])
        endCap(EndCapWidth, GlueSectionWidth, GlueSectionCenterSpacing, MainPlateThickness);
    }
}

module BasePlate(EndCapWidth, MainPlateThickness, MainLength, MainPlateWidth, GlueSectionWidth, GlueSectionCenterSpacing)
union()
{
    // Joining plate
    mainPlate(MainLength, MainPlateWidth, MainPlateThickness, EndCapWidth, GlueSectionWidth, GlueSectionCenterSpacing);
}

module openROVmainTube()
union()
{
    EndCapWidth = 7;
    MainPlateThickness = 7;
    
    MainLength = 154;
    MainPlateWidth = 88;
    
    GlueSectionWidth = 15;
    GlueSectionCenterSpacing = 30;
    
    EndCaps(EndCapWidth, MainPlateThickness, MainLength, MainPlateWidth, GlueSectionWidth, GlueSectionCenterSpacing);
    BasePlate(EndCapWidth, MainPlateThickness, MainLength, MainPlateWidth, GlueSectionWidth, GlueSectionCenterSpacing);
}

openROVmainTube();
