/*

    OpenROV Interface Board 3D Model
    Eirik Taylor, 01.06.2016

*/

module openRovInterfaceBoard() 
//Pillars where the mounting holes for the PCB need to go. Also an exclusion box for the area needed for the PCB
difference()
{
    // Size definitions
    PCB_width = 63.8;
    PCB_length = 80;
    PCB_height_topside = 16;
    PCB_board_thickness = 1.55;
    PCB_height_bottomside = 3.7;
    
    Non_ESC_distance_width = 52.53;
    Non_ESC_distance_length = 52.05;
    Non_ESC_edge_extension = 24.37;
    
    // Tolerances in printing
    PCB_perimeter_tolerance = 1; // Placed all around the PCB
    Printing_shrinkage = 0.3;
    
    // Stand-offs for mounting holes
    PCB_stand_off_size = 8;
    PCB_screw_hole_dia = 3.7;
    
    // Mounting holes
    Mounting_hole1_X = 10.16;
    Mounting_hole1_Y = 6.35;
    
    Mounting_hole2_X = 60.33;
    Mounting_hole2_Y = 6.35;
    
    Mounting_hole3_X = 60.33;
    Mounting_hole3_Y = 73.65;
    
    // Center everything
    translate([-PCB_width/2, -PCB_length/2, 0])
    
    // Mounting holes and PCB box
    union() 
    {
        difference() 
        {
            union()
            {
                // PCB box
                totalWidth = PCB_width + 2*PCB_perimeter_tolerance;
                totalLength = PCB_length + 2*PCB_perimeter_tolerance;
                totalHeightOccupied = PCB_height_topside + PCB_height_bottomside + PCB_board_thickness;
                
                translate([-PCB_perimeter_tolerance, -PCB_perimeter_tolerance, 0])
                cube([totalWidth, totalLength, totalHeightOccupied]);
                
                // Hole for the Voltage regulator on the bottom side
                V_reg_height = 9;
                V_reg_width = 17.46;
                V_reg_length = 11.43;
                Tolerance_around_vreg = 2;
                V_reg_starting_pos_x = 18.10;
                V_reg_starting_pos_y = 18.42;
                
                translate([V_reg_starting_pos_x - Tolerance_around_vreg, V_reg_starting_pos_y - Tolerance_around_vreg, PCB_height_bottomside - V_reg_height - Tolerance_around_vreg])
                cube([V_reg_width+2*Tolerance_around_vreg, V_reg_length+2*Tolerance_around_vreg, V_reg_height + Tolerance_around_vreg]);
                
                // Hole for the ESCs
                ESC_Height = 7.8;
                ExtraMargin = 2;
                ESC_start_offset = 11.5;
                
                bottomSidePCBheight = ESC_Height + V_reg_height + ExtraMargin;
                translate([PCB_width - Non_ESC_distance_width, -PCB_perimeter_tolerance + ESC_start_offset, PCB_height_bottomside-bottomSidePCBheight])
                    cube([Non_ESC_distance_width + PCB_perimeter_tolerance, Non_ESC_distance_length+PCB_perimeter_tolerance, bottomSidePCBheight]);
                
            }
            
            // Create little stand-offs for the board to sit on
            startingHeightForMountingStandOffs = -600;
            
            translate([Mounting_hole1_X, Mounting_hole1_Y, startingHeightForMountingStandOffs])
            cylinder(PCB_height_bottomside-startingHeightForMountingStandOffs,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
            translate([Mounting_hole2_X, Mounting_hole2_Y, startingHeightForMountingStandOffs])
            cylinder(PCB_height_bottomside-startingHeightForMountingStandOffs,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
            translate([Mounting_hole3_X, Mounting_hole3_Y, startingHeightForMountingStandOffs])
            cylinder(PCB_height_bottomside-startingHeightForMountingStandOffs,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
            
            // Cut out the section where the one ESC would be mounted
            translate([PCB_width - Non_ESC_distance_width, -PCB_perimeter_tolerance, PCB_height_bottomside + PCB_board_thickness])
            cube([Non_ESC_distance_width + PCB_perimeter_tolerance, Non_ESC_distance_length+PCB_perimeter_tolerance, PCB_height_topside+1]);
            
            translate([-PCB_perimeter_tolerance, -PCB_perimeter_tolerance, PCB_height_bottomside + PCB_board_thickness])
            cube([PCB_width + 2*PCB_perimeter_tolerance, Non_ESC_edge_extension+PCB_perimeter_tolerance, PCB_height_topside+1]);
        }
        
        // Bolt holes
        translate([Mounting_hole1_X, Mounting_hole1_Y, -600])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        translate([Mounting_hole2_X, Mounting_hole2_Y, -600])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        translate([Mounting_hole3_X, Mounting_hole3_Y, -600])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        
        // Hole for the DB25 connector
        StartingX_connector_outer = 24.5;
        Connector_padding_tolerance = 0.6;
        
        Connector_outer_width = 2.7;
        Connector_outer_length = 53.4;
        Connector_outer_height = 12.6;
        
        translate([-Connector_outer_width - Connector_padding_tolerance + 0.01, (StartingX_connector_outer - Connector_padding_tolerance), PCB_height_bottomside + PCB_board_thickness])
        cube([Connector_outer_width+Connector_padding_tolerance, Connector_outer_length + 2*Connector_padding_tolerance, Connector_outer_height+Connector_padding_tolerance]);
        
        StartingX_connector_inner = 30.5;
        Connector_inner_width = 7.7;
        Connector_inner_length = 42.6;
        Connector_inner_height = Connector_outer_height;
        
        translate([-Connector_inner_width - Connector_padding_tolerance + 0.01, (StartingX_connector_inner - Connector_padding_tolerance), PCB_height_bottomside + PCB_board_thickness])
        cube([Connector_inner_width+Connector_padding_tolerance, Connector_inner_length + 2*Connector_padding_tolerance, Connector_inner_height+Connector_padding_tolerance]);
    }
}

openRovInterfaceBoard();
