/*

    Raspberry Pi 2 with AdaFruit I2C PWM shield 3D Model
    Eirik Taylor, 01.06.2016

*/

module raspberryPiBoard() 
//Pillars where the mounting holes for the PCB need to go. Also an exclusion box for the area needed for the PCB
union()
{
    // Size definitions
    PCB_width = 85.0;
    PCB_length = 56.0;
    PCB_height_topside = 20;
    PCB_board_thickness = 1.3;
    PCB_height_bottomside = 4.8;
    PCB_height_topside_mounting_hole_start = 12.69 + 0.6;
    
    // Tolerances in printing
    PCB_perimeter_tolerance = 1; // Placed all around the PCB
    Printing_shrinkage = 0.3;
    
    // Stand-offs for mounting holes
    PCB_stand_off_size = 7;
    PCB_screw_hole_dia = 3.2;
    
    // Mounting holes
    Mounting_hole1_X = 3.5;
    Mounting_hole1_Y = 3.5;
    
    Mounting_hole2_X = 3.5;
    Mounting_hole2_Y = PCB_length - 3.5;
    
    Mounting_hole3_X = 58 + 3.5;
    Mounting_hole3_Y = PCB_length - 3.5;
    
    Mounting_hole4_X = 58 + 3.5;
    Mounting_hole4_Y = 3.5;
    
    // Center everything
    translate([-PCB_width/2, -PCB_length/2, 0])
    
    // Mounting holes and PCB box
    union() 
    {
        // PCB box
        totalWidth = PCB_width + 2*PCB_perimeter_tolerance;
        totalLength = PCB_length + 2*PCB_perimeter_tolerance;
        totalHeightOccupied = PCB_height_topside + PCB_height_bottomside + PCB_board_thickness;
        
        difference() 
        {
            union()
            {
                translate([-PCB_perimeter_tolerance, -PCB_perimeter_tolerance, 0])
                cube([totalWidth, totalLength, totalHeightOccupied]);
                
                // Hole for the USB power plug
                /*USB_plug_x_pos = 10.6;
                USB_Plug_width = 10;
                USB_plug_cableRoom = 40;
                USB_plug_Height = 40;
                
                translate([USB_plug_x_pos - USB_Plug_width/2, -USB_plug_cableRoom+0.01, PCB_height_bottomside+PCB_board_thickness])
                cube([USB_Plug_width, USB_plug_cableRoom, USB_plug_Height]);*/
                
                // Hole for the camera slot
                Camera_Slot_starting_pos = 32 + 13;
                Camera_slot_width = 2;
                Camera_slot_length = 20.7;
                
                translate([-PCB_perimeter_tolerance+Camera_Slot_starting_pos-Camera_slot_width/2, -PCB_perimeter_tolerance, totalHeightOccupied])
                    cube([Camera_slot_width, Camera_slot_length, PCB_additional_height_topside]);
                        
                // Match the required height better, in terms of where the servo board connections really need to go
                PCB_additional_height_topside = 20;
                PCB_extra_width = 34;
                PCB_extra_length = 10;
                PCB_extra_offset = 7;
                
                translate([-PCB_perimeter_tolerance+PCB_extra_offset, -PCB_perimeter_tolerance, totalHeightOccupied])
                    cube([PCB_extra_width-PCB_extra_offset, PCB_extra_length, PCB_additional_height_topside]);
                    
                PCB_breakout_and_power_width = 20;
                PCB_breakout_and_power_length = 29;
                
                translate([-PCB_perimeter_tolerance, PCB_perimeter_tolerance+PCB_length-PCB_breakout_and_power_length, totalHeightOccupied])
                difference()
                {
                    cube([PCB_breakout_and_power_width, PCB_breakout_and_power_length, PCB_additional_height_topside]);
                    
                    translate([0, PCB_breakout_and_power_length-PCB_extra_offset, 0])
                    cube([PCB_extra_offset, PCB_extra_offset, PCB_additional_height_topside]);
                }
                
            }
         
            // Create little stand-offs for the board to sit on
            startingHeightForMountingStandOffs = PCB_height_bottomside+PCB_board_thickness+PCB_height_topside_mounting_hole_start-0.01;
            
            translate([Mounting_hole1_X, Mounting_hole1_Y, startingHeightForMountingStandOffs])
            cylinder(600,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
            translate([Mounting_hole2_X, Mounting_hole2_Y, startingHeightForMountingStandOffs])
            cylinder(600,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
            translate([Mounting_hole3_X, Mounting_hole3_Y, startingHeightForMountingStandOffs])
            cylinder(600,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
            translate([Mounting_hole4_X, Mounting_hole4_Y, startingHeightForMountingStandOffs])
            cylinder(600,(PCB_stand_off_size/2),(PCB_stand_off_size/2));
        }
        
        // Bolt holes
        translate([Mounting_hole1_X, Mounting_hole1_Y, 0])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        translate([Mounting_hole2_X, Mounting_hole2_Y, 0])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        translate([Mounting_hole3_X, Mounting_hole3_Y, 0])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        translate([Mounting_hole4_X, Mounting_hole4_Y, 0])
        cylinder(600 + PCB_height_bottomside + 0.01,(PCB_screw_hole_dia/2),(PCB_screw_hole_dia/2));
        
        // Hole for the ethernet connector
        EthernetConnectorCableRoom = 13.5;
        EthernetConnectorWidth = 11.5;
        EthernetConnectorHeight = 12;
        
        StartingX_connector_outer = 10.25 - EthernetConnectorWidth/2;
        Connector_padding_tolerance = 1;
        
        translate([PCB_width, StartingX_connector_outer-Connector_padding_tolerance, PCB_height_bottomside+PCB_board_thickness])
        cube([EthernetConnectorCableRoom, EthernetConnectorWidth+2*Connector_padding_tolerance, EthernetConnectorHeight]);
    }
}

raspberryPiBoard();
